FigBackend

Struct FigBackend 

pub struct FigBackend { /* private fields */ }
A Backend over a standalone config file, backed by fig::Editor.

Implementations

Source

impl FigBackend

pub fn open(source: &[u8], format: Format) -> Result<Self, BackendError>

Open an editor over a copy of source parsed as format.